@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use base 'Text::MicroTemplate::File';
 
-our $VERSION = '0.01';
+our $VERSION = '0.01001';
 
 sub new {
     my $self = shift->SUPER::new(@_);
@@ -106,7 +106,13 @@ sub build {
         unless ($key =~ /^[a-zA-Z_][a-zA-Z0-9_]*$/) {
             die qq{Invalid template args key name: "$key"};
         }
-        $context->{args} .= qq{my \$$key = \$self->template_args->{$key};\n};
+
+        if (ref($self->template_args->{$key}) eq 'CODE') {
+            $context->{args} .= qq{my \$$key = \$self->template_args->{$key}->();\n};
+        }
+        else {
+            $context->{args} .= qq{my \$$key = \$self->template_args->{$key};\n};
+        }
     }
 
     $context->{blocks} ||= {};
